require_relative 'base'

puts "Baseline: (doing nothing in a loop)"
results_test{true}
puts ""
